==> kubernetes-model-admissionregistration-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1beta1/RuleWithOperationsBuilder.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class RuleWithOperationsBuilder extends io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperationsFluentImpl<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperationsBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations,io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperationsBuilder>{
  public RuleWithOperationsBuilder() {
    this(false);
  }
  public RuleWithOperationsBuilder(java.lang.Boolean validationEnabled) {
    this(new RuleWithOperations(), validationEnabled);
  }
  public RuleWithOperationsBuilder(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperationsFluent<?> fluent) {
    this(fluent, false);
  }
  public RuleWithOperationsBuilder(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperationsFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new RuleWithOperations(), validationEnabled);
  }
  public RuleWithOperationsBuilder(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperationsFluent<?> fluent,io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations instance) {
    this(fluent, instance, false);
  }
  public RuleWithOperationsBuilder(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperationsFluent<?> fluent,io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiGroups(instance.getApiGroups()); 
    fluent.withApiVersions(instance.getApiVersions()); 
    fluent.withOperations(instance.getOperations()); 
    fluent.withResources(instance.getResources()); 
    fluent.withScope(instance.getScope()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public RuleWithOperationsBuilder(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations instance) {
    this(instance,false);
  }
  public RuleWithOperationsBuilder(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiGroups(instance.getApiGroups()); 
    this.withApiVersions(instance.getApiVersions()); 
    this.withOperations(instance.getOperations()); 
    this.withResources(instance.getResources()); 
    this.withScope(instance.getScope()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperationsFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations build() {
    RuleWithOperations buildable = new RuleWithOperations(fluent.getApiGroups(),fluent.getApiVersions(),fluent.getOperations(),fluent.getResources(),fluent.getScope());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RuleWithOperationsBuilder that = (RuleWithOperationsBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-admissionregistration-6.3.1-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1beta1/RuleWithOperationsBuilder.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class RuleWithOperationsBuilder extends RuleWithOperationsFluentImpl<RuleWithOperationsBuilder> implements VisitableBuilder<RuleWithOperations,RuleWithOperationsBuilder>{
  public RuleWithOperationsBuilder() {
    this(false);
  }
  public RuleWithOperationsBuilder(Boolean validationEnabled) {
    this(new RuleWithOperations(), validationEnabled);
  }
  public RuleWithOperationsBuilder(RuleWithOperationsFluent<?> fluent) {
    this(fluent, false);
  }
  public RuleWithOperationsBuilder(RuleWithOperationsFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new RuleWithOperations(), validationEnabled);
  }
  public RuleWithOperationsBuilder(RuleWithOperationsFluent<?> fluent,RuleWithOperations instance) {
    this(fluent, instance, false);
  }
  public RuleWithOperationsBuilder(RuleWithOperationsFluent<?> fluent,RuleWithOperations instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiGroups(instance.getApiGroups()); 
    fluent.withApiVersions(instance.getApiVersions()); 
    fluent.withOperations(instance.getOperations()); 
    fluent.withResources(instance.getResources()); 
    fluent.withScope(instance.getScope()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public RuleWithOperationsBuilder(RuleWithOperations instance) {
    this(instance,false);
  }
  public RuleWithOperationsBuilder(RuleWithOperations instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiGroups(instance.getApiGroups()); 
    this.withApiVersions(instance.getApiVersions()); 
    this.withOperations(instance.getOperations()); 
    this.withResources(instance.getResources()); 
    this.withScope(instance.getScope()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  RuleWithOperationsFluent<?> fluent;
  Boolean validationEnabled;
  public RuleWithOperations build() {
    RuleWithOperations buildable = new RuleWithOperations(fluent.getApiGroups(),fluent.getApiVersions(),fluent.getOperations(),fluent.getResources(),fluent.getScope());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
